function Example(n)  %n = size of the problem.
%Function to run the example in the paper [1] with Picard method 2.
%PHD Jorge Barrios Ginart - Universidade Federal de Gois 2014
%Version 13/11/2014 
%[1] O.P.Ferreira, S.Z. Nmeth. Projection onto simplicial cones by
%Picards method. Preprint.

sprintf('Size of the problem %d',n)
% Initialize method parameters.

%//Parameters 
np   = 100;             %number of problems.
nIP   = 1;              %number of initial points.       
tola  = -7;             %tolerance exponent a.
step  =-3;              %step between a and b.
tolb  = -13;            %tolerance exponent b for solve problems from tol=10^tola to 10^tolb.
bMat = 1000000;         %bound for random values.
mIt  = 10000;           %maximum accepted number of iterations.
repit= 10;              %number of executions for each problem.


I    = eye(n);          %N-by-N identity matrix.

%Generate the matrix A 
A=getA(n);

for i=1:np 
u  = -bMat + (2*bMat).*rand(n,1);          %generate the solution u.
z  = A'\(((A'*A-I)*max(u,0))+u);           %computing z from A and u.
mIP=zeros(n,nIP);
for q=1:nIP   
mIP(:,q) = -bMat + (2*bMat).*rand(n,1);    %generate the initial points x0.
end  
setProbE(mIP,z,u,i,n);
end

cont=0;
st=zeros(2,length(tola:step:tolb));
sd=zeros(2,length(tola:step:tolb));

for exp=tola:step:tolb    
    cont=cont+1;
    tol(cont)=10^exp; 
    timeP2= zeros(repit,1);
    tpP2  = zeros(np,1);
    ipP2  = zeros(np,1);
    sdtpP2  = zeros(np,1);
    sdipP2  = zeros(np,1);
    tpP2IP  = zeros(nIP,1);
    ipP2IP  = zeros(nIP,1);

    for i=1:np     
    [mIP z u] = getProbE(i,n,nIP);
        for j=1:nIP
            for k=1:repit 
                [ipP2IP(j) timeP2(k)]=Picard2(n,A,mIP(:,j),z,tol(cont),mIt,u);
            end   
            tpP2IP(j)=median(timeP2);      
        end 
        tpP2(i)=mean(tpP2IP); 
        ipP2(i)=mean(ipP2IP); 
        sdtpP2(i)=std(tpP2IP); 
        sdipP2(i)=std(ipP2IP);
    end
    
    st(:,cont)=[mean(tpP2(find((tpP2>0)&(tpP2<Inf))))
                mean(ipP2(find((ipP2>0)&(ipP2<Inf))))];
    sd(:,cont)=[mean(sdtpP2(find((sdtpP2>=0)&(sdtpP2<Inf))))
                mean(sdipP2(find((sdipP2>=0)&(sdipP2<Inf))))];
   
    clear tol  timeP2 tpP2;         
end              
sprintf('Tol %0.5g',10.^[tola:step:tolb])  
sprintf('Number of problems: %d, Size of the problem: %d, Number of IPoints: %d\nMean  Time: %d  %d  %d\nSTD:        %d  %d  %d\nMean  Iter: %d  %d  %d\nSTD:        %d  %d  %d'...
            ,np,n,nIP,...
            st(1,1),st(1,2),st(1,3),...
            sd(1,1),sd(1,2),sd(1,3),...
            st(2,1),st(2,2),st(2,3),...
            sd(2,1),sd(2,2),sd(2,3))
end


